@@ -34,12 +34,20 @@ public:
     QList<PuzzleItem *> pieces() const;
     QPointF emptyPlace();
     void setEmptyPlace(const QPointF &place);
-    bool areAllPiecesOk() const;
+    bool areAllPiecesOk();
     void setMovingPieces();
 
 public slots:
-    void setPieces(const QList<PuzzleItem *> pieces);
+    void setPieces(const QList<PuzzleItem *> pieces, bool shuffle = true);
     void shufflePieces();
+    bool restoreGame();
+    bool saveGame();
+
+signals:
+    void gameWon();
+
+protected:
+    void closeEvent(QCloseEvent *event);
 
 private:
     GameView(QWidget *parent = 0);
