@@ -37,12 +37,15 @@ MainWindow::MainWindow(QWidget *parent) :
     settingsDialog_ = new SettingsDialog(this);
 
     setWindowTitle(tr("ImPuzzle"));
+
+    connect(GameView::instance(), SIGNAL(gameWon()), this, SLOT(gameEnded()));
 }
 
 void MainWindow::createMenu()
 {
     menu_ = menuBar()->addMenu("");
     menu_->addAction(newGameAction_);
+    menu_->addAction(saveAction_);
     menu_->addAction(importAction_);
 }
 
@@ -57,6 +60,10 @@ void MainWindow::createActions()
 
     settingsAction_ = new QAction(tr("Settings"), this);
     connect(settingsAction_, SIGNAL(triggered()), this, SLOT(settingsClicked()));
+
+    saveAction_ = new QAction(tr("Save game"), this);
+    connect(saveAction_, SIGNAL(triggered()), GameView::instance(), SLOT(saveGame()));
+    saveAction_->setDisabled(true);
 }
 
 void MainWindow::importClicked()
@@ -71,9 +78,17 @@ void MainWindow::newGameClicked()
     settingsDialog_->exec();
 
     GameView::instance()->setPieces(ImageImporter::instance()->newPieces(Settings::instance()->image(), Settings::instance()->pieceCount()));
+    saveAction_->setEnabled(true);
 }
 
 void MainWindow::settingsClicked()
 {
 
 }
+
+void MainWindow::gameEnded()
+{
+    if(saveAction_->isEnabled()) {
+        saveAction_->setDisabled(true);
+    }
+}
