@@ -36,6 +36,7 @@ private slots:
     void newGameClicked();
     void importClicked();
     void settingsClicked();
+    void gameEnded();
 
 private:
     void createActions();
@@ -44,6 +45,7 @@ private:
     QAction *newGameAction_;
     QAction *importAction_;
     QAction *settingsAction_;
+    QAction *saveAction_;
 
     QMenu *menu_;
 
