@@ -1,12 +1,14 @@
 #include "settings.h"
+#include "defines.h"
 
 Settings *Settings::instance_ = 0;
 
 Settings::Settings(QObject *parent) :
         QObject(parent)
 {
-    pieceCount_ = 12;
+    pieceCount_ = EASY_PIECE_COUNT;
     image_ = 0;
+    imagePath_ = "";
 }
 
 Settings *Settings::instance()
@@ -37,3 +39,13 @@ void Settings::setImage(const QPixmap &image)
 {
     image_ = image;
 }
+
+QString Settings::imagePath() const
+{
+    return imagePath_;
+}
+
+void Settings::setImagePath(const QString &path)
+{
+    imagePath_ = path;
+}
